@@ -1,10 +1,10 @@
 test_that("images are picked up", {
-
   skip_if_not(getRversion() >= "4.1")
 
   # Depending on how we are testing the logo may reside in one of these locations
   logo <- system.file("man", "figures", "logo.png", package = "marquee")
-  if (logo == "") logo <- system.file("help", "figures", "logo.png", package = "marquee")
+  if (logo == "")
+    logo <- system.file("help", "figures", "logo.png", package = "marquee")
 
   grob <- textGrob("test")
   gg <- ggplot2::ggplot()
